@@ -10,21 +10,21 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.4.6"
+#define MARIADB_CLIENT_VERSION_STR	"10.4.7"
 #define MARIADB_BASE_VERSION		"mariadb-10.4"
-#define MARIADB_VERSION_ID		100406
+#define MARIADB_VERSION_ID		100407
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/run/mysqld/mysqld.sock"
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100406
-#define MYSQL_SERVER_VERSION            "10.4.6-MariaDB"
+#define MYSQL_VERSION_ID                100407
+#define MYSQL_SERVER_VERSION            "10.4.7-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.1.2"
-#define MARIADB_PACKAGE_VERSION_ID 30102
+#define MARIADB_PACKAGE_VERSION "3.1.3"
+#define MARIADB_PACKAGE_VERSION_ID 30103
 #define MARIADB_SYSTEM_TYPE "Linux"
 #define MARIADB_MACHINE_TYPE "armv5tel"
-#define MARIADB_PLUGINDIR "/usr//usr/lib/mysql/plugin"
+#define MARIADB_PLUGINDIR "/usr/lib/mysql/plugin"
 
 /* mysqld compile time options */
 #ifndef MYSQL_CHARSET
